4155 kevin.lewis@stripped 2012-08-02 [merge]
Merge 14315223 from mysql-5.6
modified:
storage/innobase/handler/ha_innodb.cc
4154 Inaam Rana 2012-08-02 [merge]
merge from mysql-5.6
modified:
storage/innobase/srv/srv0start.cc
=== modified file 'storage/innobase/handler/ha_innodb.cc'
--- a/storage/innobase/handler/ha_innodb.cc revid:inaam.rana@stripped
+++ b/storage/innobase/handler/ha_innodb.cc revid:kevin.lewis@stripped
@@ -2854,12 +2854,12 @@ innobase_init(
srv_data_home = (innobase_data_home_dir ? innobase_data_home_dir :
default_path);
/* Set default InnoDB data file size to 10 MB and let it be
auto-extending. Thus users can use InnoDB in >= 4.0 without having
to specify any startup options. */
if (!innobase_data_file_path) {
- innobase_data_file_path = (char*) "ibdata1:10M:autoextend";
+ innobase_data_file_path = (char*) "ibdata1:12M:autoextend";
}
/* Since InnoDB edits the argument in the next call, we make another
No bundle (reason: useless for push emails).
@@ -2854,12 +2854,12 @@ innobase_init(
srv_data_home = (innobase_data_home_dir ? innobase_data_home_dir :
default_path);
- /* Set default InnoDB data file size to 10 MB and let it be
+ /* Set default InnoDB data file size to 12 MB and let it be
auto-extending. Thus users can use InnoDB in >= 4.0 without having
to specify any startup options. */
| Thread |
|---|
| • bzr push into mysql-trunk branch (kevin.lewis:4154 to 4155) | kevin.lewis | 3 Aug |